==> hledger-web-1.3-22-armv7h.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.3
id: hledger-web-1.3-FOZEXVb3nf5GknRwUF8iBm
key: hledger-web-1.3-FOZEXVb3nf5GknRwUF8iBm
license: GPL-3
maintainer: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
author: Simon Michael <simon@joyful.com>
exposed: True
exposed-modules:
    Application Foundation Handler.AddForm Handler.Common
    Handler.JournalR Handler.RegisterR Handler.RootR Handler.SidebarR
    Handler.Utils Hledger.Web Hledger.Web.Main Hledger.Web.WebOptions
    Import Settings Settings.Development Settings.StaticFiles
hidden-modules: Paths_hledger_web
abi: 58d4e1a75ca1e079dcb46dbcca2e32de
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hledger-web-1.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/hledger-web-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.3-FOZEXVb3nf5GknRwUF8iBm
depends:
    HUnit-1.6.0.0-60ZLMGxowdyCquCGGOoE3I base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0 bytestring-0.10.8.1
    clientsession-0.9.1.2-9kKpoTVy5mACXNsbrHrhsB
    cmdargs-0.10.17-gTr0lzwrHbBcQQ47pfTGo
    conduit-extra-1.1.16-5YILVd78SGn9wwYaAO3g7W
    data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq directory-1.3.0.0
    filepath-1.4.1.1 hjsmin-0.2.0.2-KVIZEO0GpxR4sKyr7sGnCY
    hledger-1.3-2B9LP5YwnkJ5QBtFa4XKKR
    hledger-lib-1.3-92jrkUykEU38AWlukeydoO
    http-client-0.5.7.0-8CqgjLtDELe98Oo6kiK06v
    http-conduit-2.2.3.2-IoaUAYqXYwn560NYVXNhee
    json-0.9.1-G9lxq5WdrzUDT7HRdlHQ5I
    megaparsec-5.3.1-9NkUd2RGYlu1wtR645IhSo
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    shakespeare-2.0.13-7tkYqZznbwm6X0y1el8pnL template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0 wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    wai-extra-3.0.20.0-KhzK8oymyugEE3OMSKvDM4
    wai-handler-launch-3.0.2.2-7FAkvOcnS508Haae5KyVmQ
    warp-3.2.13-Bfpm5qCALCDGPTf6JBLKn
    yaml-0.8.23.3-8FJZhPKX9fmLLFoNaNncOM
    yesod-1.4.5-2kqWIbuJrVmHLSDr5Vyvkc
    yesod-core-1.4.35.1-1mVL8sWbX6p9rV4wDBNYOu
    yesod-form-1.4.13-H8UCN399hIx431TbfoMrnx
    yesod-static-1.5.3.1-CZgyMKrNSbMArsUjBaVGLT
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-web-1.3-26-armv7h.pkg.tar.xz: usr/share/haskell/register/hledger-web.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-web
version: 1.3
id: hledger-web-1.3-DP8ji8N7QQtGli8sVyvF6j
key: hledger-web-1.3-DP8ji8N7QQtGli8sVyvF6j
license: GPL-3
maintainer: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Web interface for the hledger accounting tool
description:
    This is hledger'\''s web interface.
    It provides a more user-friendly and collaborative UI than the
    command-line or curses-style interfaces.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
author: Simon Michael <simon@joyful.com>
exposed: True
exposed-modules:
    Application Foundation Handler.AddForm Handler.Common
    Handler.JournalR Handler.RegisterR Handler.RootR Handler.SidebarR
    Handler.Utils Hledger.Web Hledger.Web.Main Hledger.Web.WebOptions
    Import Settings Settings.Development Settings.StaticFiles
hidden-modules: Paths_hledger_web
abi: 5e28202d6b1bbe4fed6e4b56cb129c57
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hledger-web-1.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/hledger-web-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger-web
hs-libraries: HShledger-web-1.3-DP8ji8N7QQtGli8sVyvF6j
depends:
    HUnit-1.6.0.0-60ZLMGxowdyCquCGGOoE3I base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0 bytestring-0.10.8.1
    clientsession-0.9.1.2-9kKpoTVy5mACXNsbrHrhsB
    cmdargs-0.10.17-gTr0lzwrHbBcQQ47pfTGo
    conduit-extra-1.1.16-ENJUyud795q910vrFDK54q
    data-default-0.7.1.1-BNa3MzH41nV77yjS9K2Umq directory-1.3.0.0
    filepath-1.4.1.1 hjsmin-0.2.0.2-KVIZEO0GpxR4sKyr7sGnCY
    hledger-1.3-Lu67cVRIDEQERXcR7GRB6Z
    hledger-lib-1.3-92jrkUykEU38AWlukeydoO
    http-client-0.5.7.0-8CqgjLtDELe98Oo6kiK06v
    http-conduit-2.2.3.2-KnSG9WpYeFM5Bm3i54BAzx
    json-0.9.1-C2FDZAxuh5hCIxQmYtJQ5P
    megaparsec-5.3.1-9NkUd2RGYlu1wtR645IhSo
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    shakespeare-2.0.13-KCXl8uUSnCQKF0QGMG79cz template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0 wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    wai-extra-3.0.20.0-EDR0e3J4jH2AUZMugvBabx
    wai-handler-launch-3.0.2.2-1yA2JUA2cvO3M08QwDp5Jb
    warp-3.2.13-2zIfvy7PaU822kbwwTyJQq
    yaml-0.8.23.3-Zl0UWmB8DzHSZcW3qkjNP
    yesod-1.4.5-p7jkloSXZDLCjoyutK61L
    yesod-core-1.4.36-KXTQpWc8apKDKyCtw7RxJ0
    yesod-form-1.4.13-L6TeS1xOdrwDQ8QAFy7A2E
    yesod-static-1.5.3.1-B2d5tB7DxA2HNcj8jDRhos
haddock-interfaces: /usr/share/doc/hledger-web/html/hledger-web.haddock
haddock-html: /usr/share/doc/hledger-web/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
